@@ -3,9 +3,13 @@
 {-# LANGUAGE FlexibleContexts  #-}
 {-# LANGUAGE OverloadedStrings #-}
 {-# LANGUAGE RecordWildCards   #-}
+{-# OPTIONS_GHC -Wno-incomplete-record-updates #-}
 
 module Hledger.UI.ErrorScreen
- (errorScreen
+ (esNew
+ ,esUpdate
+ ,esDraw
+ ,esHandle
  ,uiCheckBalanceAssertions
  ,uiReloadJournal
  ,uiReloadJournalIfChanged
@@ -23,40 +27,27 @@ import Lens.Micro ((^.))
 import Text.Megaparsec
 import Text.Megaparsec.Char
 
-import Hledger.Cli hiding (progname,prognameandversion)
+import Hledger.Cli hiding (mode, progname,prognameandversion)
 import Hledger.UI.UIOptions
 import Hledger.UI.UITypes
 import Hledger.UI.UIState
 import Hledger.UI.UIUtils
+import Hledger.UI.UIScreens
 import Hledger.UI.Editor
 
-errorScreen :: Screen
-errorScreen = ErrorScreen{
-   sInit    = esInit
-  ,sDraw    = esDraw
-  ,sHandle  = esHandle
-  ,esError  = ""
-  }
-
-esInit :: Day -> Bool -> UIState -> UIState
-esInit _ _ ui@UIState{aScreen=ErrorScreen{}} = ui
-esInit _ _ _ = error "init function called with wrong screen type, should not happen"  -- PARTIAL:
-
 esDraw :: UIState -> [Widget Name]
-esDraw UIState{aopts=UIOpts{uoCliOpts=copts}
-              ,aScreen=ErrorScreen{..}
+esDraw UIState{aScreen=ES ESS{..}
               ,aMode=mode
               } =
   case mode of
-    Help       -> [helpDialog copts, maincontent]
-    -- Minibuffer e -> [minibuffer e, maincontent]
+    Help       -> [helpDialog, maincontent]
     _          -> [maincontent]
   where
     maincontent = Widget Greedy Greedy $ do
-      render $ defaultLayout toplabel bottomlabel $ withAttr "error" $ str $ esError
+      render $ defaultLayout toplabel bottomlabel $ withAttr (attrName "error") $ str $ _essError
       where
         toplabel =
-              withAttr ("border" <> "bold") (str "Oops. Please fix this problem then press g to reload")
+              withAttr (attrName "border" <> attrName "bold") (str "Oops. Please fix this problem then press g to reload")
               -- <+> (if ignore_assertions_ copts then withAttr ("border" <> "query") (str " ignoring") else str " not ignoring")
 
         bottomlabel = quickhelp
@@ -74,44 +65,46 @@ esDraw UIState{aopts=UIOpts{uoCliOpts=copts}
 
 esDraw _ = error "draw function called with wrong screen type, should not happen"  -- PARTIAL:
 
-esHandle :: UIState -> BrickEvent Name AppEvent -> EventM Name (Next UIState)
-esHandle ui@UIState{aScreen=ErrorScreen{..}
-                   ,aopts=UIOpts{uoCliOpts=copts}
-                   ,ajournal=j
-                   ,aMode=mode
-                   }
-         ev =
-  case mode of
-    Help ->
-      case ev of
-        VtyEvent (EvKey (KChar 'q') []) -> halt ui
-        VtyEvent (EvKey (KChar 'l') [MCtrl]) -> redraw ui
-        VtyEvent (EvKey (KChar 'z') [MCtrl]) -> suspend ui
-        _                    -> helpHandle ui ev
+esHandle :: BrickEvent Name AppEvent -> EventM Name UIState ()
+esHandle ev = do
+  ui0 <- get'
+  case ui0 of
+    ui@UIState{aScreen=ES ESS{..}
+              ,aopts=UIOpts{uoCliOpts=copts}
+              ,ajournal=j
+              ,aMode=mode
+              } ->
+      case mode of
+        Help ->
+          case ev of
+            VtyEvent (EvKey (KChar 'q') []) -> halt
+            VtyEvent (EvKey (KChar 'l') [MCtrl]) -> redraw
+            VtyEvent (EvKey (KChar 'z') [MCtrl]) -> suspend ui
+            _                    -> helpHandle ev
 
-    _ -> do
-      let d = copts^.rsDay
-      case ev of
-        VtyEvent (EvKey (KChar 'q') []) -> halt ui
-        VtyEvent (EvKey KEsc        []) -> continue $ uiCheckBalanceAssertions d $ resetScreens d ui
-        VtyEvent (EvKey (KChar c)   []) | c `elem` ['h','?'] -> continue $ setMode Help ui
-        VtyEvent (EvKey (KChar 'E') []) -> suspendAndResume $ void (runEditor pos f) >> uiReloadJournalIfChanged copts d j (popScreen ui)
-          where
-            (pos,f) = case parsewithString hledgerparseerrorpositionp esError of
-                        Right (f,l,c) -> (Just (l, Just c),f)
-                        Left  _       -> (endPosition, journalFilePath j)
-        e | e `elem` [VtyEvent (EvKey (KChar 'g') []), AppEvent FileChange] ->
-          liftIO (uiReloadJournal copts d (popScreen ui)) >>= continue . uiCheckBalanceAssertions d
---           (ej, _) <- liftIO $ journalReloadIfChanged copts d j
---           case ej of
---             Left err -> continue ui{aScreen=s{esError=err}} -- show latest parse error
---             Right j' -> continue $ regenerateScreens j' d $ popScreen ui  -- return to previous screen, and reload it
-        VtyEvent (EvKey (KChar 'I') []) -> continue $ uiCheckBalanceAssertions d (popScreen $ toggleIgnoreBalanceAssertions ui)
-        VtyEvent (EvKey (KChar 'l') [MCtrl]) -> redraw ui
-        VtyEvent (EvKey (KChar 'z') [MCtrl]) -> suspend ui
-        _ -> continue ui
+        _ -> do
+          d <- liftIO getCurrentDay
+          case ev of
+            VtyEvent (EvKey (KChar 'q') []) -> halt
+            VtyEvent (EvKey KEsc        []) -> put' $ uiCheckBalanceAssertions d $ resetScreens d ui
+            VtyEvent (EvKey (KChar c)   []) | c `elem` ['h','?'] -> put' $ setMode Help ui
+            VtyEvent (EvKey (KChar 'E') []) -> suspendAndResume $ void (runEditor pos f) >> uiReloadJournalIfChanged copts d j (popScreen ui)
+              where
+                (pos,f) = case parsewithString hledgerparseerrorpositionp _essError of
+                            Right (f',l,c) -> (Just (l, Just c),f')
+                            Left  _       -> (endPosition, journalFilePath j)
+            e | e `elem` [VtyEvent (EvKey (KChar 'g') []), AppEvent FileChange] ->
+              liftIO (uiReloadJournal copts d (popScreen ui)) >>= put' . uiCheckBalanceAssertions d
+              -- (ej, _) <- liftIO $ journalReloadIfChanged copts d j
+              -- case ej of
+              --   Left err -> continue ui{aScreen=s{esError=err}} -- show latest parse error
+              --   Right j' -> continue $ regenerateScreens j' d $ popScreen ui  -- return to previous screen, and reload it
+            VtyEvent (EvKey (KChar 'I') []) -> put' $ uiCheckBalanceAssertions d (popScreen $ toggleIgnoreBalanceAssertions ui)
+            VtyEvent (EvKey (KChar 'l') [MCtrl]) -> redraw
+            VtyEvent (EvKey (KChar 'z') [MCtrl]) -> suspend ui
+            _ -> return ()
 
-esHandle _ _ = error "event handler called with wrong screen type, should not happen"  -- PARTIAL:
+    _ -> errorWrongScreenType "event handler"
 
 -- | Parse the file name, line and column number from a hledger parse error message, if possible.
 -- Temporary, we should keep the original parse error location. XXX
@@ -155,39 +148,48 @@ uiReloadJournal :: CliOpts -> Day -> UIState -> IO UIState
 uiReloadJournal copts d ui = do
   ej <-
     let copts' = enableForecastPreservingPeriod ui copts
-    in journalReload copts'
+    in runExceptT $ journalReload copts'
+  -- dbg1IO "uiReloadJournal before reload" (map tdescription $ jtxns $ ajournal ui)
   return $ case ej of
-    Right j  -> regenerateScreens j d ui
+    Right j  ->
+      -- dbg1 "uiReloadJournal after reload" (map tdescription $ jtxns j) $
+      regenerateScreens j d ui
     Left err ->
       case ui of
-        UIState{aScreen=s@ErrorScreen{}} -> ui{aScreen=s{esError=err}}
-        _                                -> screenEnter d errorScreen{esError=err} ui
+        UIState{aScreen=ES _} -> ui{aScreen=esNew err}
+        _                      -> pushScreen (esNew err) ui
+      -- XXX GHC 9.2 warning:
+      -- hledger-ui/Hledger/UI/ErrorScreen.hs:164:59: warning: [-Wincomplete-record-updates]
+      --     Pattern match(es) are non-exhaustive
+      --     In a record-update construct:
+      --         Patterns of type ‘Screen’ not matched:
+      --             AccountsScreen _ _ _ _ _
+      --             RegisterScreen _ _ _ _ _ _
+      --             TransactionScreen _ _ _ _ _ _
 
 -- | Like uiReloadJournal, but does not re-parse the journal if the file(s)
 -- have not changed since last loaded. Always regenerates the screens though,
 -- since the provided options or today-date may have changed.
 uiReloadJournalIfChanged :: CliOpts -> Day -> Journal -> UIState -> IO UIState
 uiReloadJournalIfChanged copts d j ui = do
-  (ej, _changed) <-
-    let copts' = enableForecastPreservingPeriod ui copts
-    in journalReloadIfChanged copts' d j
+  let copts' = enableForecastPreservingPeriod ui copts
+  ej <- runExceptT $ journalReloadIfChanged copts' d j
   return $ case ej of
-    Right j' -> regenerateScreens j' d ui
-    Left err ->
-      case ui of
-        UIState{aScreen=s@ErrorScreen{}} -> ui{aScreen=s{esError=err}}
-        _                                -> screenEnter d errorScreen{esError=err} ui
+    Right (j', _) -> regenerateScreens j' d ui
+    Left err -> case aScreen ui of
+        ES _ -> ui{aScreen=esNew err}
+        _    -> pushScreen (esNew err) ui
 
 -- Re-check any balance assertions in the current journal, and if any
 -- fail, enter (or update) the error screen. Or if balance assertions
 -- are disabled, do nothing.
 uiCheckBalanceAssertions :: Day -> UIState -> UIState
-uiCheckBalanceAssertions d ui@UIState{ajournal=j}
+uiCheckBalanceAssertions _d ui@UIState{ajournal=j}
   | ui^.ignore_assertions = ui
   | otherwise =
     case journalCheckBalanceAssertions j of
       Nothing  -> ui
       Just err ->
         case ui of
-          UIState{aScreen=s@ErrorScreen{}} -> ui{aScreen=s{esError=err}}
-          _                                -> screenEnter d errorScreen{esError=err} ui
+          UIState{aScreen=ES sst} -> ui{aScreen=ES sst{_essError=err}}
+          _                        -> pushScreen (esNew err) ui
